import { useMemo } from "react";
import { Stack, Typography } from "@mui/material";
import { InternalLink } from "@ess-ics/ce-ui-common";
import { getNoOfIOCs, getNoOfHosts, isBatchJob } from "../JobUtils";
import { ActionTypeIconText } from "../JobIcons";
import { ACTION_TYPES } from "../JobData";
import { JobRevisionChip } from "../JobRevisionChip";
import { Job } from "../../../store/deployApi";

export const JobDetailsColumn = ({ job }: { job: Job }) => {
  const isBatchOperation = isBatchJob(job.action);

  const noOfIOCs = useMemo(() => {
    if (isBatchOperation) {
      return getNoOfIOCs(job.jobs);
    }
  }, [job, isBatchOperation]);

  const noOfHosts = useMemo(() => {
    if (isBatchOperation) {
      return getNoOfHosts(job.jobs);
    }
  }, [job, isBatchOperation]);

  return (
    <Stack>
      <ActionTypeIconText action={job.action} />
      {!isBatchOperation ? (
        <Stack>
          <Stack
            flexDirection="row"
            gap={1}
            alignItems="center"
            flexWrap="wrap"
          >
            <InternalLink
              to={`/iocs/${job.iocId}`}
              label={`IOC Details, ${job.iocName}`}
            >
              {job.iocName}
            </InternalLink>
            {job?.action === ACTION_TYPES.DEPLOY &&
              job?.gitReference &&
              job?.gitProjectId && (
                <JobRevisionChip
                  gitReference={job.gitReference}
                  gitProjectId={job.gitProjectId}
                />
              )}
          </Stack>
          <Stack
            flexDirection="row"
            gap={1}
            alignItems="baseline"
            flexWrap="wrap"
          >
            <InternalLink
              to={`/hosts/${job?.host?.hostId}`}
              label={`Host details, ${job.host?.hostName}`}
            >
              {job?.host?.hostName}
            </InternalLink>
            <Typography variant="body2">{job?.host?.network}</Typography>
          </Stack>
        </Stack>
      ) : (
        <Stack>
          <Typography variant="body2">
            {noOfIOCs} {noOfIOCs && noOfIOCs > 1 ? "IOCs" : "IOC"}
          </Typography>
          <Typography variant="body2">
            {noOfHosts} {noOfHosts && noOfHosts > 1 ? "Hosts" : "Host"}
          </Typography>
        </Stack>
      )}
    </Stack>
  );
};
